// ----------------
// caldisp.js      
//                 
// Calendar display
// ----------------

// -------------------------------------------------------------
// Function: caldisp          
//                  
// Display a calendar based on the current year, month, and day.
//                  
// Arguments:       
//                  
// bcMonthYear   - background color for month/year
//
// bcWeekHdr     - background color for week header
//
// bcDay         - background color for non-highlighted days
//
// bcHiliteDay   - background color for highlighted day
//
// bcEmptySquare - background color for empty square
//               
// Return:       
//               
// none          
// -------------------------------------------------------------

function caldisp (bcMonthYear, bcWeekHdr, bcDay, bcHiliteDay, bcEmptySquare)
{
   // Get the current date.

   var d = new Date ();

   // Determine the maximum number of days in a month. If the current year is
   // a leap year, advance the number of days for February from 28 to 29.

   var daysInMonth = new Array (31, 28, 31, 30, 31, 30,
                                31, 31, 30, 31, 30, 31);

   if (isleap (d.getFullYear ()))
       daysInMonth [1]++;

   var maxDays = daysInMonth [d.getMonth ()];

   // Create an array of month names so we can display the current month's
   // name in the calendar.

   var months = new Array ("January", "February", "March",
                           "April", "May", "June",
                           "July", "August", "September",
                           "October", "November", "December");

   // Start creating the calendar in an HTML table. Display the current month
   // and year, centered in the table's header.

   document.writeln ("<table border=1>");
   document.writeln ("<th style=\"background-color: " + bcMonthYear + ";\"" +
                     " colspan=7>");
   document.writeln ("<center>" + months [d.getMonth ()] +
                     " " + d.getFullYear () + "</center>");
   document.writeln ("</th>");

   // Determine the weekday on which the first day of the month falls. This is
   // used to determine the table column for displaying the first month day.

   var dayOfMonth = d.getDate ();
   d.setDate (1);
   var dayOfWeek = d.getDay ();
   d.setDate (dayOfMonth);

   // Create the weekday header row.

   document.writeln ("<tr>");
   document.writeln ("<td style=\"background-color: " + bcWeekHdr +
                     ";\"><b><center>S</center></b></td>");
   document.writeln ("<td style=\"background-color: " + bcWeekHdr +
                     ";\"><b><center>M</center></b></td>");
   document.writeln ("<td style=\"background-color: " + bcWeekHdr +
                     ";\"><b><center>T</center></b></td>");
   document.writeln ("<td style=\"background-color: " + bcWeekHdr +
                     ";\"><b><center>W</center></b></td>");
   document.writeln ("<td style=\"background-color: " + bcWeekHdr +
                     ";\"><b><center>T</center></b></td>");
   document.writeln ("<td style=\"background-color: " + bcWeekHdr +
                     ";\"><b><center>F</center></b></td>");
   document.writeln ("<td style=\"background-color: " + bcWeekHdr +
                     ";\"><b><center>S</center></b></td>");
   document.writeln ("</tr>");

   // Initialize day counter to 1.

   var day = 1;

   // Create the HTML table's day rows. Display days in suitable columns, and
   // highlight the current day using boldface type.

   for (row = 0; row < 6; row++)
   {
        document.writeln ("<tr>");
        for (col = 0; col < 7; col++)
        {
             if (day == dayOfMonth && !(row == 0 && col < dayOfWeek))
                 document.writeln ("<td style=\"background-color: " +
                                   bcHiliteDay + ";\">");
             else
             if ((row == 0 && col < dayOfWeek) || day > maxDays)
                 document.writeln ("<td style=\"background-color: " +
                                   bcEmptySquare + ";\">");
             else
                 document.writeln ("<td style=\"background-color: " +
                                   bcDay + ";\">");

             if ((row == 0 && col < dayOfWeek) || day > maxDays)
                 document.writeln ("&nbsp;");
             else
             {
                 if (day == dayOfMonth)
                     document.write ("<b>");
                 document.writeln (day++);
                 if (day-1 == dayOfMonth)
                     document.write ("</b>");
                 document.writeln ("</td>");
             }
        }
        document.writeln ("</tr>");
   }

   // Stop creating the HTML table.

   document.writeln ("</table>");
}

// ------------------------------------------------
// Function: isleap
//                                                 
// Determine a year's leap-year status.            
//                                                 
// Arguments:                                      
//                                                 
// year - the year whose status must be determined 
//                                                 
// Return:                                         
//                                                 
// true if the year is a leap year, otherwise false
// ------------------------------------------------

function isleap (year)
{
   return (!(year & 3) && year % 100 || !(year % 400));
}
